pub enum WitnessSegment {
Public,
Precommit,
Private,
}Variants
Public
The public segment contains constant and input/output witness values.
Precommit
The precommit segment contains values committed in a separate oracle before the private segment. These are zero-knowledge hidden but not prunable or rearrangeable.
Private
The private segment contains the remaining witness values, which are hidden from the verifier.